==> jc-1.4.0.tar.gz: java/lang/ref/WeakReference.h <==
// public class java.lang.ref.WeakReference

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 14fe490ec89fb98 java_lang_ref_WeakReference

// header file dependencies
// @dep_header java_lang_ref_Reference

#include "java/lang/ref/Reference.h"

#ifndef _JC_java_lang_ref_WeakReference_H_
#define _JC_java_lang_ref_WeakReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_WeakReference$sub_refs	_jc_java_lang_ref_WeakReference$sub_refs;
typedef struct _jc_java_lang_ref_WeakReference$sub_nonrefs	_jc_java_lang_ref_WeakReference$sub_nonrefs;
typedef struct _jc_java_lang_ref_WeakReference$refs	_jc_java_lang_ref_WeakReference$refs;
typedef struct _jc_java_lang_ref_WeakReference$nonrefs	_jc_java_lang_ref_WeakReference$nonrefs;
typedef struct _jc_java_lang_ref_WeakReference$object	_jc_java_lang_ref_WeakReference$object;

typedef const struct _jc_java_lang_ref_WeakReference$vmethods	_jc_java_lang_ref_WeakReference$vmethods;
typedef const struct _jc_java_lang_ref_WeakReference$vtable	_jc_java_lang_ref_WeakReference$vtable;
typedef const struct _jc_java_lang_ref_WeakReference$vtype	_jc_java_lang_ref_WeakReference$vtype;

// Constructors
extern void _jc_java_lang_ref_WeakReference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_ref_WeakReference$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_lang_ref_WeakReference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_WeakReference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *);

// Virtual methods structure
struct _jc_java_lang_ref_WeakReference$vmethods {
};

// Vtable
struct _jc_java_lang_ref_WeakReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_WeakReference$vmethods	java_lang_ref_WeakReference;
};

// Vtype
struct _jc_java_lang_ref_WeakReference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_WeakReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_WeakReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ref_WeakReference$refs {
    _jc_java_lang_ref_WeakReference$sub_refs	java_lang_ref_WeakReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_WeakReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_WeakReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_WeakReference$sub_nonrefs	java_lang_ref_WeakReference;
};

// Object instance structure
struct _jc_java_lang_ref_WeakReference$object {
	_jc_java_lang_ref_WeakReference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_WeakReference$vtype	*vtype;
	_jc_java_lang_ref_WeakReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_WeakReference$vtype _jc_java_lang_ref_WeakReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_WeakReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_WeakReference$class_object;

#endif	/* _JC_java_lang_ref_WeakReference_H_ */

==> jc-1.4.6.tar.gz: java/lang/ref/WeakReference.h <==
// public class java.lang.ref.WeakReference

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 14fe490ec89fb98 java_lang_ref_WeakReference

// header file dependencies
// @dep_header java_lang_ref_Reference

#include "java/lang/ref/Reference.h"

#ifndef _JC_java_lang_ref_WeakReference_H_
#define _JC_java_lang_ref_WeakReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_WeakReference$sub_refs	_jc_java_lang_ref_WeakReference$sub_refs;
typedef struct _jc_java_lang_ref_WeakReference$sub_nonrefs	_jc_java_lang_ref_WeakReference$sub_nonrefs;
typedef struct _jc_java_lang_ref_WeakReference$refs	_jc_java_lang_ref_WeakReference$refs;
typedef struct _jc_java_lang_ref_WeakReference$nonrefs	_jc_java_lang_ref_WeakReference$nonrefs;
typedef struct _jc_java_lang_ref_WeakReference$object	_jc_java_lang_ref_WeakReference$object;

typedef const struct _jc_java_lang_ref_WeakReference$vmethods	_jc_java_lang_ref_WeakReference$vmethods;
typedef const struct _jc_java_lang_ref_WeakReference$vtable	_jc_java_lang_ref_WeakReference$vtable;
typedef const struct _jc_java_lang_ref_WeakReference$vtype	_jc_java_lang_ref_WeakReference$vtype;

// Constructors
extern void _jc_java_lang_ref_WeakReference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_ref_WeakReference$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ref_WeakReference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_WeakReference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_ref_WeakReference$vmethods {
};

// Vtable
struct _jc_java_lang_ref_WeakReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_WeakReference$vmethods	java_lang_ref_WeakReference;
};

// Vtype
struct _jc_java_lang_ref_WeakReference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_WeakReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_WeakReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ref_WeakReference$refs {
    _jc_java_lang_ref_WeakReference$sub_refs	java_lang_ref_WeakReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_WeakReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_WeakReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_WeakReference$sub_nonrefs	java_lang_ref_WeakReference;
};

// Object instance structure
struct _jc_java_lang_ref_WeakReference$object {
	_jc_java_lang_ref_WeakReference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_WeakReference$vtype	*vtype;
	_jc_java_lang_ref_WeakReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_WeakReference$vtype _jc_java_lang_ref_WeakReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_WeakReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_WeakReference$class_object;

#endif	/* _JC_java_lang_ref_WeakReference_H_ */
